aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLinus Torvalds <torvalds@linux-foundation.org>2010-11-02 09:05:21 -0400
committerLinus Torvalds <torvalds@linux-foundation.org>2010-11-02 09:05:21 -0400
commit85b4f0af1a0ecb2148364e6b9d6cb779d5720592 (patch)
tree990e6e71c1782ddf0b32870d8aa56d883155ec31
parent4966cb355eecf368200916f98eb8d0abe6edd6a4 (diff)
parent6491f4c4f04ec84879a751d3a406bc903478441a (diff)
downloaduemacs-85b4f0af1a0ecb2148364e6b9d6cb779d5720592.tar.gz
Merge branch 'master' of git://git.kernel.org/pub/scm/editors/uemacs/uemacs
-rw-r--r--efunc.h2
-rw-r--r--estruct.h12
-rw-r--r--exec.c14
3 files changed, 14 insertions, 14 deletions
diff --git a/efunc.h b/efunc.h
index dd491e9..82b37b1 100644
--- a/efunc.h
+++ b/efunc.h
@@ -258,7 +258,7 @@ extern int storeproc(int f, int n);
extern int execproc(int f, int n);
extern int execbuf(int f, int n);
extern int dobuf(struct buffer *bp);
-extern void freewhile(WHBLOCK *wp);
+extern void freewhile(struct while_block *wp);
extern int execfile(int f, int n);
extern int dofile(char *fname);
extern int cbuf(int f, int n, int bufnum);
diff --git a/estruct.h b/estruct.h
index b530091..3317192 100644
--- a/estruct.h
+++ b/estruct.h
@@ -623,12 +623,12 @@ typedef struct VDESC {
the following structure
*/
-typedef struct WHBLOCK {
- struct line *w_begin; /* ptr to !while statement */
- struct line *w_end; /* ptr to the !endwhile statement */
- int w_type; /* block type */
- struct WHBLOCK *w_next; /* next while */
-} WHBLOCK;
+struct while_block {
+ struct line *w_begin; /* ptr to !while statement */
+ struct line *w_end; /* ptr to the !endwhile statement */
+ int w_type; /* block type */
+ struct while_block *w_next; /* next while */
+};
#define BTWHILE 1
#define BTBREAK 2
diff --git a/exec.c b/exec.c
index 5e41272..fcbb313 100644
--- a/exec.c
+++ b/exec.c
@@ -430,9 +430,9 @@ int dobuf(struct buffer *bp)
int c; /* temp character */
int force; /* force TRUE result? */
struct window *wp; /* ptr to windows to scan */
- WHBLOCK *whlist; /* ptr to !WHILE list */
- WHBLOCK *scanner; /* ptr during scan */
- WHBLOCK *whtemp; /* temporary ptr to a WHBLOCK */
+ struct while_block *whlist; /* ptr to !WHILE list */
+ struct while_block *scanner; /* ptr during scan */
+ struct while_block *whtemp; /* temporary ptr to a struct while_block */
char *einit; /* initial value of eline */
char *eline; /* text of line to execute */
char tkn[NSTRING]; /* buffer to evaluate an expresion in */
@@ -465,7 +465,7 @@ int dobuf(struct buffer *bp)
/* if is a while directive, make a block... */
if (eline[0] == '!' && eline[1] == 'w' && eline[2] == 'h') {
- whtemp = (WHBLOCK *) malloc(sizeof(WHBLOCK));
+ whtemp = (struct while_block *)malloc(sizeof(struct while_block));
if (whtemp == NULL) {
noram:mlwrite
("%%Out of memory during while scan");
@@ -487,7 +487,7 @@ int dobuf(struct buffer *bp)
("%%!BREAK outside of any !WHILE loop");
goto failexit;
}
- whtemp = (WHBLOCK *) malloc(sizeof(WHBLOCK));
+ whtemp = (struct while_block *)malloc(sizeof(struct while_block));
if (whtemp == NULL)
goto noram;
whtemp->w_begin = lp;
@@ -832,9 +832,9 @@ int dobuf(struct buffer *bp)
/*
* free a list of while block pointers
*
* WHBLOCK *wp; head of structure to free
*/
-void freewhile(WHBLOCK *wp)
+void freewhile(struct while_block *wp)
{
if (wp == NULL)
return;
@@ -832,9 +832,9 @@ int dobuf(struct buffer *bp)
* free a list of while block pointers
*
- * WHBLOCK *wp; head of structure to free
+ * struct while_block *wp; head of structure to free
*/